@@ -53,7 +53,7 @@ class WebCoverageService_2_0_1(WCSBase):
         else:
             raise KeyError("No content named %s" % name)
 
-    def __init__(self, url, xml, cookies, auth=None):
+    def __init__(self, url, xml, cookies, auth=None, timeout=30):
         super(WebCoverageService_2_0_1, self).__init__(auth=auth)
         self.version = "2.0.1"
         self.url = url
@@ -64,7 +64,7 @@ class WebCoverageService_2_0_1(WCSBase):
         if xml:
             self._capabilities = reader.readString(xml)
         else:
-            self._capabilities = reader.read(self.url)
+            self._capabilities = reader.read(self.url, self.timeout)
 
         # check for exceptions
         se = self._capabilities.find("ServiceException")
@@ -130,6 +130,7 @@ class WebCoverageService_2_0_1(WCSBase):
         resz=None,
         parameter=None,
         method="Get",
+        timeout=30,
         **kwargs
     ):
         """Request and return a coverage from the WCS as a file-like object
@@ -214,7 +215,7 @@ class WebCoverageService_2_0_1(WCSBase):
 
         log.debug("WCS 2.0.1 DEBUG: Second part of URL: %s" % data)
 
-        u = openURL(base_url, data, method, self.cookies, auth=self.auth)
+        u = openURL(base_url, data, method, self.cookies, auth=self.auth, timeout=timeout)
         return u
 
     def getOperationByName(self, name):
