@@ -170,14 +170,13 @@ def openURL(url_base, data=None, method='Get', cookies=None, username=None, pass
             auth.password = password
         if cert:
             auth.cert = cert
-        if verify and not auth.verify:
-            auth.verify = verify
+        verify = verify and auth.verify
     else:
         auth = Authentication(username, password, cert, verify)
     if auth.username and auth.password:
         rkwargs['auth'] = (auth.username, auth.password)
     rkwargs['cert'] = auth.cert
-    rkwargs['verify'] = auth.verify
+    rkwargs['verify'] = verify
 
     # FIXUP for WFS in particular, remove xml style namespace
     # @TODO does this belong here?
@@ -293,7 +292,7 @@ def add_namespaces(root, ns_keys):
         # We can't re-add an existing namespaces.  Get a list of current
         # namespaces in use
         existing_namespaces = set()
-        for elem in root.getiterator():
+        for elem in root.iter():
             if elem.tag[0] == "{":
                 uri, tag = elem.tag[1:].split("}")
                 existing_namespaces.add(namespaces.get_namespace_from_url(uri))
@@ -592,6 +591,10 @@ def dump(obj, prefix=''):
 def getTypedValue(data_type, value):
     '''Utility function to cast a string value to the appropriate XSD type. '''
 
+    # If the default value is empty
+    if value is None:
+        return
+
     if data_type == 'boolean':
         return True if value.lower() == 'true' else False
     elif data_type == 'integer':
